@@ -1,52 +1,57 @@
 # Kill Bill colorset
 # Written by: Maciej Delmanowski <harnir@linux.net.pl>
 
-SetEnv Colorset-Name "Kill Bill"
-SetEnv Colorset-Author "Maciej Delmanowski <harnir@linux.net.pl>"
+SetEnv Colorset_Name "Kill Bill"
 
 # What colorsets do we use?
 Read $./colorset-definition
 
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
 # QuakeConsole, thumbnailed windows
-Colorset $[cs-quakeconsole] \
+Colorset $[infostore.cs_quakeconsole] \
 Foreground "black", Background "black", \
 Hilight "black", Shadow "black", \
 IconAlpha 70
 
 
-Colorset $[cs-panel-inactive] \
+Colorset $[infostore.cs_panel_inactive] \
 Foreground "black", Background "black", \
 Tint "yellow" 70, RootTransparent, \
 fgTint, IconAlpha, IconTint
 
-Colorset $[cs-panel-active] \
+Colorset $[infostore.cs_panel_active] \
 Foreground "black", Background "black", \
 Hilight "black", Shadow "black", \
 Tint "yellow" 40, RootTransparent
 
-Colorset $[cs-panel-wininactive] \
+Colorset $[infostore.cs_panel_wininactive] \
 Foreground "black", Background "black", \
 Hilight "yellow", Shadow "yellow", \
 Tint "gold" 30, RootTransparent
 
-Colorset $[cs-panel-winactive] \
+Colorset $[infostore.cs_panel_winactive] \
 Foreground "black", Background "black", \
 Hilight "yellow", Shadow "yellow", \
 Tint "yellow" 90, RootTransparent
 
-Colorset $[cs-panel-border] \
+Colorset $[infostore.cs_panel_border] \
 Background "yellow"
 
-Colorset $[cs-menu-inactive] \
+Colorset $[infostore.cs_menu_inactive] \
 Foreground "black", Background "black", \
 Hilight "black", Shadow "black", \
 Tint "yellow" 70, RootTransparent
 
-Colorset $[cs-menu-active] \
+Colorset $[infostore.cs_menu_active] \
 Foreground "black", Background "#b1a700", \
 Hilight "red", Shadow "red"
 
+Colorset $[infostore.cs_icon_active] \
+Foreground "black", Background "black", \
+Hilight "black", Shadow "black", \
+RootTransparent
+
+Colorset $[infostore.cs_transparent] Transparent, RootTransparent
 
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
 # Additional variables
@@ -55,4 +60,3 @@ SetEnv ExternalFontColor "black"
 
 SetEnv TrayerTint "0xFFFF00"
 SetEnv TrayerAlpha "77"
-
